@@ -1,30 +1,22 @@
-#!/usr/bin/perl -w
+#!perl
 
 package Math::BigInt::Named::English;
 
-require 5.005_02;
+use 5.006001;
 use strict;
+use warnings;
 
-use Exporter;
-use Math::BigInt;
-use vars qw($VERSION @ISA $PACKAGE @EXPORT_OK
-            $accuracy $precision $round_mode $div_scale);
+use Math::BigInt::Named;
+our @ISA = qw< Math::BigInt::Named >;
 
-@ISA = qw(Exporter Math::BigInt);
-
-$VERSION = 0.01;
-
-# Globals
-$accuracy = $precision = undef;
-$round_mode = 'even';
-$div_scale = 40;
+our $VERSION = '0.03';
 
 sub name
   {
   # output the name of the number
   my ($x) = shift;
   $x = Math::BigInt->new($x) unless ref($x);
- 
+
   my $self = ref($x);
 
   return '' if $x->is_nan();
@@ -38,7 +30,7 @@ sub name
     $ret = 'minus ';
     $y->babs();
     }
-  if ($y < 1000) 
+  if ($y < 1000)
     {
     return $ret . $self->_triple($y,1,0);
     }
@@ -51,18 +43,10 @@ sub name
     $index++;
     }
   $ret =~ s/\s+$//;	# trailing spaces
-  return $ret;
+  $ret;
   }
 
-sub from_name
-  {
-  # create a Math::BigInt::Name from a name string
-  my $name = shift;
-
-  my $x = Math::BigInt->bnan();
-  }
-
-my $SMALL = [ qw/ 
+my $SMALL = [ qw/
   zero
   one
   two
@@ -77,7 +61,7 @@ my $SMALL = [ qw/
   eleven
   twelf
   thirteen
-  fourteen 
+  fourteen
   fifteen
   sixteen
   seventeen
@@ -95,7 +79,7 @@ my $ZEHN = [ qw /
   seventy
   eighty
   ninety
-  / ];  
+  / ];
 
 my $HUNDERT = [ qw /
   one
@@ -107,7 +91,7 @@ my $HUNDERT = [ qw /
   seven
   eight
   nine
-  / ];  
+  / ];
 
 my $TRIPLE = [ qw /
   mi
@@ -123,18 +107,18 @@ my $TRIPLE = [ qw /
 sub _triple_name
   {
   my ($self,$index,$number) = @_;
-  
+
   return '' if $index == 0 || $number->is_zero();
   return 'thousand' if $index == 1;
- 
+
   my $postfix = 'llion'; my $plural = 's';
-  if ($index & 1 == 1)
+  if (($index & 1) == 1)
     {
     $postfix = 'lliard';
     }
   $postfix .= $plural unless $number->is_one();
   $index -= 2;
-  return $TRIPLE->[$index >> 1] . $postfix;
+  $TRIPLE->[$index >> 1] . $postfix;
   }
 
 sub _triple
@@ -153,31 +137,25 @@ sub _triple
   my $rc = '';
   $rc = "$HUNDERT->[$hundert-1]hundred" if !$hundert->is_zero();
 
-  my $concat = ''; $concat = 'and' if $rc ne ''; 
+  my $concat = ''; $concat = 'and' if $rc ne '';
   return $rc if $rem->is_zero();
   return $rc . $concat . $SMALL->[$rem] if $rem < scalar @$SMALL;
-  
+
   my $zehn; ($zehn,$rem) = $rem->bdiv(10);
 
-  my $last = ''; 
+  my $last = '';
   $last = $HUNDERT->[$rem-1] if !$rem->is_zero(); 	# 31, 32..
   $last = $ZEHN->[$zehn-1].$last if !$zehn->is_zero();  	# 1,2,3..
-  
+
   $rc . $last;
   }
 
-#sub import
-#  {
-#  my $self = shift;
-#  Math::BigInt->import(@_);
-#  $self->SUPER::import(@_);                     # need it for subclasses
-#  #$self->export_to_level(1,$self,@_);           # need this ?
-#  }
-
 1;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Math::BigInt::Named::English - Math::BigInts that know their name in English
@@ -200,9 +178,37 @@ with their name in English to Math::BigInt::Named.
 Usually you do not need to use this directly, but rather go via
 L<Math::BigInt::Named>.
 
+=head1 METHODS
+
+=head2 name()
+
+	print Math::BigInt::Name->name( 123 );
+
+Convert a BigInt to a name.
+
+=head2 from_name()
+
+	my $bigint = Math::BigInt::Name->from_name('hundertzwanzig');
+
+Create a Math::BigInt::Name from a name string. B<Not yet implemented!>
+
 =head1 BUGS
 
-None know yet. Please see also L<Math::BigInt::Named>.
+For information about bugs and how to report them, see the BUGS section in the
+documentation available with the perldoc command.
+
+    perldoc Math::BigInt::Named
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Math::BigInt::Named::English
+
+For more information, see the SUPPORT section in the documentation available
+with the perldoc command.
+
+    perldoc Math::BigInt::Named
 
 =head1 LICENSE
 
@@ -211,15 +217,20 @@ the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Math::BigFloat> and L<Math::Big> as well as L<Math::BigInt::BitVect>,
-L<Math::BigInt::Pari> and  L<Math::BigInt::GMP>.
-
-The package at
-L<http://search.cpan.org/search?dist=Math-BigInt-Named> may
-contain more documentation and examples as well as testcases.
+L<Math::BigInt::Named>, L<Math::BigIn> and L<Math::BigFloat>.
 
 =head1 AUTHORS
 
-(C) by Tels in late 2001, early 2002. Based on work by Chris London Noll.
+=over 4
+
+=item *
+
+(C) by Tels http://bloodgate.com in late 2001, early 2002, 2007.
+
+=item *
+
+Maintained by Peter John Acklam E<lt>pjacklam@gmail.com<gt>, 2016-.
+
+=back
 
 =cut
